@@ -11,8 +11,11 @@ class Image(ItemRenderer):
         image_format: ImageType,
         alt: str,
         caption: Optional[str] = None,
-        **kwargs
+        **kwargs,
     ):
+        if image is None:
+            raise ValueError(f"Image may not be None (alt={alt}, caption={caption})")
+
         super().__init__(
             "image",
             {
@@ -21,7 +24,7 @@ class Image(ItemRenderer):
                 "alt": alt,
                 "caption": caption,
             },
-            **kwargs
+            **kwargs,
         )
 
     def __repr__(self) -> str:
