@@ -24,6 +24,7 @@ def render_date(config: Settings, summary: Dict[str, Any]) -> Dict[str, Any]:
         "Date",
         summary["alerts"],
         summary["description"],
+        style=config.html.style,
     )
 
     table1 = Table(
@@ -53,35 +54,59 @@ def render_date(config: Settings, summary: Dict[str, Any]) -> Dict[str, Any]:
                 "value": fmt_bytesize(summary["memory_size"]),
                 "alert": False,
             },
-        ]
+        ],
+        style=config.html.style,
     )
 
     table2 = Table(
         [
             {"name": "Minimum", "value": fmt(summary["min"]), "alert": False},
             {"name": "Maximum", "value": fmt(summary["max"]), "alert": False},
-        ]
+        ],
+        style=config.html.style,
     )
 
-    mini_histo = Image(
-        mini_histogram(
-            config, summary["histogram"][0], summary["histogram"][1], date=True
-        ),
-        image_format=image_format,
-        alt="Mini histogram",
-    )
+    if isinstance(summary["histogram"], list):
+        mini_histo = Image(
+            mini_histogram(
+                config,
+                [x[0] for x in summary["histogram"]],
+                [x[1] for x in summary["histogram"]],
+                date=True,
+            ),
+            image_format=image_format,
+            alt="Mini histogram",
+        )
+    else:
+        mini_histo = Image(
+            mini_histogram(
+                config, summary["histogram"][0], summary["histogram"][1], date=True
+            ),
+            image_format=image_format,
+            alt="Mini histogram",
+        )
 
     template_variables["top"] = Container(
         [info, table1, table2, mini_histo], sequence_type="grid"
     )
 
+    if isinstance(summary["histogram"], list):
+        hist_data = histogram(
+            config,
+            [x[0] for x in summary["histogram"]],
+            [x[1] for x in summary["histogram"]],
+            date=True,
+        )
+    else:
+        hist_data = histogram(
+            config, summary["histogram"][0], summary["histogram"][1], date=True
+        )
+
     # Bottom
     bottom = Container(
         [
             Image(
-                histogram(
-                    config, summary["histogram"][0], summary["histogram"][1], date=True
-                ),
+                hist_data,
                 image_format=image_format,
                 alt="Histogram",
                 caption=f"<strong>Histogram with fixed size bins</strong> (bins={len(summary['histogram'][1]) - 1})",
